@@ -1,26 +1,33 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 #
 #
 # A Net::DRI example
-# See also t/Net/DRI/Protocol/EPP/Extensions/CAT.t
+# See also t/613cat_epp.t
 
-use utf8;
 use strict;
-use warnings;
 
 use Net::DRI;
 
+use DateTime::Duration;
+ 
 my $CLID='YOUR TEST CLIENT ID'; ### Change this information
 my $PASS='YOUR PASSWORD'; ### Change this information
 
-my $dri=Net::DRI->new({cache_ttl=>10,logging=>'files'});
+my $dri=Net::DRI->new(10);
 
-my $ok=eval {
+eval {
 ############################################################################################################
-$dri->add_registry('puntCAT',{clid=>$CLID});
+$dri->add_registry('CAT',{clid=>$CLID});
+
+my $file='results-'.time().'.log';
+open(my $fh,'>>',$file) || die $!;
+select($fh);
+$|++;
+select(STDOUT);
+print "Dumping XML exchange to $file\n";
 
 ## This connects to .CAT server for tests
-my $rc=$dri->target('puntCAT')->add_current_profile('profile1','epp',{remote_host=>'epp.ote.puntcat.corenic.net',client_login=>$CLID,client_password=>$PASS});
+my $rc=$dri->target('CAT')->new_current_profile('profile1',[{log_fh=>$fh,defer=>0,socktype=>'ssl',remote_host=>'epp.ote.puntcat.corenic.net',remote_port=>700,protocol_connection=>'Net::DRI::Protocol::EPP::Connection',protocol_version=>1,client_login=>$CLID,client_password=>$PASS}]);
 
 die($rc) unless $rc->is_success(); ## Here we catch all errors during setup of transport, such as authentication errors
 
@@ -63,7 +70,7 @@ $cs->set($c2,'billing');
 $cs->set($c3,'tech');
 $cs->set($c4,'admin');
 print "Attempting to create domain $dom\n";
-$rc=$dri->domain_create($dom,{pure_create=>1,duration=>$dri->local_object('duration',years => 1),ns=>$nso,contact=>$cs,lang=>'ca',ens=>{auth=>{id=>'FASE3-100000',key=>'0000'},intended_use=>'To test Net::DRI'},auth=>{pw=>'XYZE'}});
+$rc=$dri->domain_create_only($dom,{duration=>DateTime::Duration->new(years =>1),ns=>$nso,contact=>$cs,lang=>'ca',ens=>{auth=>{id=>'FASE3-100000',key=>'0000'},intended_use=>'To test Net::DRI'},auth=>{pw=>'XYZE'}});
 print "Created $dom is_success=".$rc->is_success()."\n";
 
 
@@ -80,7 +87,7 @@ $rc=$dri->domain_info($dom);
 print "domain_info OK\n" if $rc->is_success();
 
 my $ns='ns.titi-'.time().'.fr';
-$nso=$dri->local_object('hosts')->set('ns.titi-'.time().'.fr');
+$nso=$dri->local_object('hosts')->new('ns.titi-'.time().'.fr');
 print "NS=$ns\n";
 
 print "Creating $ns\n";
@@ -94,7 +101,7 @@ $rc=$dri->domain_update_ns_del($dom,$nso);
 print "ns_del OK=".$rc->is_success()."\n";
 $rc=$dri->domain_info($dom);
 
-my $s=$dri->local_object('status')->no('update');
+my $s=$dri->create_status()->no('update');
 $rc=$dri->domain_update_status_add($dom,$s);
 print "status_add OK=".$rc->is_success()."\n";
 $rc=$dri->domain_info($dom);
@@ -102,7 +109,7 @@ $rc=$dri->domain_update_status_del($dom,$s);
 print "status_del OK=".$rc->is_success()."\n";
 $rc=$dri->domain_info($dom);
 
-$rc=$dri->domain_delete($dom,{pure_delete => 1});
+$rc=$dri->domain_delete_only($dom);
 print "domain_delete OK=".$rc->is_success()."\n";
 
 $rc=$dri->contact_delete($c1);
@@ -115,18 +122,18 @@ $rc=$dri->contact_delete($c4);
 print "Contact4 deleted successfully\n" if $rc->is_success();
 
 $dri->end();
+close($fh);
 };
 
-if (! $ok)
+if ($@)
 { 
- my $err=$@;
  print "\n\nAn EXCEPTION happened !\n";
- if (ref $err)
+ if (ref($@))
  {
-  $err->print();
+  $@->print();
  } else
  {
-  print $err;
+  print($@);
  }
 } else
 {
