@@ -16,6 +16,7 @@ $dri->add_registry('VNDS',{});
 $rc=$dri->target('VNDS')->new_current_profile('profile1','whois');
 die($rc) unless $rc->is_success();
 display('nsi.com',$dri);
+display('laposte.net',$dri);
 
 $dri->add_registry('AERO',{});
 $rc=$dri->target('AERO')->new_current_profile('profile1','whois');
@@ -42,6 +43,16 @@ $rc=$dri->target('BIZ')->new_current_profile('profile1','whois');
 die($rc) unless $rc->is_success();
 display('neulevel.biz',$dri);
 
+$dri->add_registry('MOBI',{});
+$rc=$dri->target('MOBI')->new_current_profile('profile1','whois');
+die($rc) unless $rc->is_success();
+display('buongiorno.mobi',$dri);
+
+$dri->add_registry('NAME',{});
+$rc=$dri->target('NAME')->new_current_profile('profile1','whois');
+die($rc) unless $rc->is_success();
+display('sudoku.name',$dri);
+
 
 $dri->end();
 };
@@ -79,7 +90,7 @@ sub display
    print $k.': '.($dri->get_info($k) || 'n/a')."\n";
   }
   print 'status: '.join(' ',$dri->get_info('status')->list_status())."\n";
-  print 'ns: '.join(' ',$dri->get_info('ns')->get_names())."\n";
+  print 'ns: '.join(' ',$dri->get_info('ns')->get_names())."\n" if defined($dri->get_info('ns'));
  }
  my $cs=$dri->get_info('contact');
  if ($cs)
