@@ -1,7 +1,8 @@
 ## Domain Registry Interface, .BIZ policies
 ##
-## Copyright (c) 2007,2008,2009 Distribute.IT Pty Ltd, www.distributeit.com.au, Rony Meyer <perl@spot-light.ch>. All rights reserved.
-##           (c) 2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Distribute.IT Pty Ltd, www.distributeit.com.au,
+##                    Rony Meyer <perl@spot-light.ch>.
+##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,16 +12,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::DRD::BIZ;
 
 use strict;
-use warnings;
-
 use base qw/Net::DRI::DRD/;
 
-use DateTime::Duration;
+use Net::DRI::DRD::ICANN;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -50,8 +54,8 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2009 Distribute.IT Pty Ltd, E<lt>http://www.distributeit.com.auE<gt>, Rony Meyer <perl@spot-light.ch>.
-          (c) 2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+Copyright (c) 2007 Distribute.IT Pty Ltd, E<lt>http://www.distributeit.com.auE<gt>,
+Rony Meyer <perl@spot-light.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -67,10 +71,13 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my $class=shift;
+ my $proto=shift;
+ my $class=ref($proto) || $proto;
+
  my $self=$class->SUPER::new(@_);
  $self->{info}->{host_as_attr}=0;
- $self->{info}->{contact_i18n}=6; ## INT only or INT+LOC (but not LOC only)
+
+ bless($self,$class);
  return $self;
 }
 
@@ -78,15 +85,26 @@ sub periods  { return map { DateTime::Duration->new(years => $_) } (1..10); }
 sub name     { return 'BIZ'; }
 sub tlds     { return ('biz'); }
 sub object_types { return ('domain','contact','ns'); }
-sub profile_types { return qw/epp whois/; }
+
+sub transport_protocol_compatible
+{
+ my ($self,$to,$po)=@_;
+ my $pn=$po->name();
+ my $pv=$po->version();
+ my $tn=$to->name();
+
+ return 1 if (($pn eq 'EPP') && ($tn eq 'socket_inet'));
+ return 1 if (($pn eq 'Whois') && ($tn eq 'socket_inet'));
+ return;
+}
 
 sub transport_protocol_default
 {
- my ($self,$type)=@_;
+ my ($drd,$ndr,$type)=@_;
+ $type='' if (!defined($type) || ref($type));
+ return ('Net::DRI::Transport::Socket','Net::DRI::Protocol::EPP') unless ($type);
+ return ('Net::DRI::Transport::Socket',[{defer=>1,close_after=>1,socktype=>'tcp',remote_host=>'whois.nic.biz',remote_port=>43,protocol_connection=>'Net::DRI::Protocol::Whois::Connection',protocol_version=>1}],'Net::DRI::Protocol::Whois',[]) if (lc($type) eq 'whois');
 
- return ('Net::DRI::Transport::Socket',{},'Net::DRI::Protocol::EPP::Extensions::BIZ',{})              if $type eq 'epp';
- return ('Net::DRI::Transport::Socket',{remote_host=>'whois.nic.biz'},'Net::DRI::Protocol::Whois',{}) if $type eq 'whois';
- return;
 }
 
 ####################################################################################################
@@ -94,10 +112,26 @@ sub transport_protocol_default
 sub verify_name_domain
 {
  my ($self,$ndr,$domain,$op)=@_;
- return $self->_verify_name_rules($domain,$op,{check_name => 1,
-                                               my_tld => 1,
-                                               icann_reserved => 1,
-                                              });
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ my $r=$self->SUPER::check_name($domain,1);
+ return $r if ($r);
+ return 10 unless $self->is_my_tld($domain);
+ return 11 if Net::DRI::DRD::ICANN::is_reserved_name($domain,$op);
+
+ return 0;
+}
+
+sub domain_operation_needs_is_mine
+{
+ my ($self,$ndr,$domain,$op)=@_;
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ return unless defined($op);
+
+ return 1 if ($op=~m/^(?:renew|update|delete)$/);
+ return 0 if ($op eq 'transfer');
+ return;
 }
 
 ####################################################################################################
