@@ -1,7 +1,7 @@
 ## Domain Registry Interface, Infrastructure ENUM.AT policy on reserved names
 ## Contributed by Michael Braunoeder from ENUM.AT <michael.braunoeder@enum.at>
 ##
-## Copyright (c) 2006,2008-2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,20 +11,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::DRD::IENUMAT;
 
 use strict;
-use warnings;
-
 use base qw/Net::DRI::DRD/;
 
 use Net::DRI::Util;
-use DateTime::Duration;
 
-## The domain renew command are not implemented at the ienum43 EPP server, domains are renewed automatically
-__PACKAGE__->make_exception_for_unavailable_operations(qw/domain_renew/);
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -54,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008-2011 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -70,36 +69,84 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my $class=shift;
+ my $proto=shift;
+ my $class=ref($proto) || $proto;
+
  my $self=$class->SUPER::new(@_);
  $self->{info}->{host_as_attr}=0;
+
+ bless($self,$class);
+
  return $self;
 }
 
+sub is_my_tld
+{
+   my ($self,$domain)=@_;
+   my ($tld) = uc($self->tlds());
+
+   return 1 if (uc($domain) =~ /.*$tld$/);
+   return 0;
+}
+
 sub periods  { return map { DateTime::Duration->new(years => $_) } (1); }
 sub name     { return 'IENUMAT'; }
 sub tlds     { return ('i.3.4.e164.arpa'); }
 sub object_types { return ('domain'); }
-sub profile_types { return qw/epp/; }
+
+sub transport_protocol_compatible
+{
+ my ($self,$to,$po)=@_;
+ my $pn=$po->name();
+ my $tn=$to->name();
+
+ return 1 if (($pn eq 'EPP') && ($tn eq 'socket_inet'));
+ return;
+}
 
 sub transport_protocol_default
 {
- my ($self,$type)=@_;
-
- return ('Net::DRI::Transport::Socket',{},'Net::DRI::Protocol::EPP::Extensions::IENUMAT',{}) if $type eq 'epp';
- return;
+ return ('Net::DRI::Transport::Socket','Net::DRI::Protocol::EPP::Extensions::IENUMAT');
 }
 
 ####################################################################################################
 
 sub verify_name_domain
 {
- my ($self,$ndr,$domain,$op)=@_;
- return $self->_verify_name_rules($domain,$op,{check_name_no_dots => 1, ## is this correct?
-                                               my_tld_not_strict => 1, ## is this correct?
-                                               no_country_code => 1,
-                                              });
+ my ($self,$ndr,$domain)=@_;
+ $domain=$ndr unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+
+
+ my @splited = split /\./,$domain;
+ my $count = @splited;
+ $count--;
+ my $r=$self->SUPER::check_name($domain,$count);
+ return $r if ($r);
+ return 10 unless $self->is_my_tld($domain);
+
+ my @d=split(/\./,$domain);
+
+ return 11 if exists($Net::DRI::Util::CCA2{uc($d[0])});
+
+ return 0;
 }
 
+sub domain_operation_needs_is_mine
+{
+    my ($self,$ndr,$domain,$op)=@_;
+    ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+    return unless defined($op);
+
+    return 1 if ($op=~m/^(?:update|delete)$/);
+    return 0 if ($op eq 'transfer');
+    return; #renew not implemented
+}
+
+
+## The domain renew command are not implemented at the ienum43 EPP server, domains are renewed automatically
+sub domain_renew        { Net::DRI::Exception->die(0,'DRD',4,'No domain renew available in IENUM.AT'); }
+
 ####################################################################################################
 1;
