@@ -1,8 +1,7 @@
 ## Domain Registry Interface, .NU policies
 ##
-## Copyright (c) 2007,2008,2009 HEXONET Support GmbH, http://www.hexonet.com,
+## Copyright (c) 2007 HEXONET Support GmbH, http://www.hexonet.com,
 ##                    Alexander Biehl <info@hexonet.com>.
-##           (c) 2010,2011 Patrick Mevzek <netdri@dotandco.com>
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -13,16 +12,17 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::DRD::NU;
 
 use strict;
-use warnings;
-
 use base qw/Net::DRI::DRD/;
 
-use DateTime::Duration;
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -52,9 +52,8 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2009 HEXONET Support GmbH, E<lt>http://www.hexonet.comE<gt>,
+Copyright (c) 2007 HEXONET Support GmbH, E<lt>http://www.hexonet.comE<gt>,
 Alexander Biehl <info@hexonet.com>.
-(c) 2010,2011 Patrick Mevzek <netdri@dotandco.com>
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -70,23 +69,62 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my $class=shift;
+ my $proto=shift;
+ my $class=ref($proto) || $proto;
+
  my $self=$class->SUPER::new(@_);
  $self->{info}->{host_as_attr}=0;
+
+ bless($self,$class);
  return $self;
 }
 
-sub periods  { return map { DateTime::Duration->new(years => $_) } (1..10); }
+sub periods  { return map { DateTime::Duration->new(years => $_) } (2..10); }
 sub name     { return 'NU'; }
 sub tlds     { return ('nu'); }
 sub object_types { return ('domain','contact','ns'); }
-sub profile_types { return qw/epp/; }
+
+sub transport_protocol_compatible
+{
+ my ($self,$to,$po)=@_;
+ my $pn=$po->name();
+ my $pv=$po->version();
+ my $tn=$to->name();
+
+ return 1 if (($pn eq 'EPP') && ($tn eq 'socket_inet'));
+ return;
+}
 
 sub transport_protocol_default
 {
- my ($self,$type)=@_;
+ my ($drd,$ndr,$type)=@_;
+ $type='' if (!defined($type) || ref($type));
+ return ('Net::DRI::Transport::Socket','Net::DRI::Protocol::EPP') unless ($type);
+}
 
- return ('Net::DRI::Transport::Socket',{},'Net::DRI::Protocol::EPP',{}) if $type eq 'epp';
+####################################################################################################
+
+sub verify_name_domain
+{
+ my ($self,$ndr,$domain,$op)=@_;
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ my $r=$self->SUPER::check_name($domain,1);
+ return $r if ($r);
+ return 10 unless $self->is_my_tld($domain);
+
+ return 0;
+}
+
+sub domain_operation_needs_is_mine
+{
+ my ($self,$ndr,$domain,$op)=@_;
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ return unless defined($op);
+
+ return 1 if ($op=~m/^(?:renew|update|delete)$/);
+ return 0 if ($op eq 'transfer');
  return;
 }
 
