@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Handling of contact data for .BE
 ##
-## Copyright (c) 2006,2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,18 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Data::Contact::BE;
 
 use strict;
-use warnings;
-
 use base qw/Net::DRI::Data::Contact/;
+__PACKAGE__->mk_accessors(qw(vat lang));
 
 use Net::DRI::Exception;
 
-__PACKAGE__->register_attributes(qw(vat lang));
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -71,7 +73,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -116,20 +118,19 @@ sub validate
 
 sub init
 {
- my ($self,$what,$ndr)=@_;
+ my ($self,$what)=@_;
+
  if ($what eq 'create')
  {
   my $a=$self->auth();
   $self->auth({pw=>''}) unless ($a && (ref($a) eq 'HASH') && exists($a->{pw}));
-  $self->srid('ABCD') unless defined $self->srid(); ## we can not choose the ID
  }
- return;
 }
 
 sub type
 {
  my ($self,$what)=@_;
- if (defined $what && $what)
+ if (defined($what) && $what)
  {
   $what='registrant' if $what eq 'licensee';
   $self->{type}=$what;
