@@ -1,6 +1,6 @@
 ## Domain Registry Interface, AFNIC Email Message
 ##
-## Copyright (c) 2006,2009,2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,20 +10,24 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Protocol::AFNIC::Email::Message;
 
 use strict;
-use warnings;
 
 use base qw(Class::Accessor::Chained::Fast Net::DRI::Protocol::Message);
 __PACKAGE__->mk_accessors(qw(version trid email_from client_auth));
 
 use MIME::Entity ();
+use Encode ();
 
 use Net::DRI::Protocol::ResultStatus;
-use Net::DRI::Util;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -53,7 +57,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2009,2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -69,7 +73,9 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my ($class,$trid,$otype,$oaction)=@_;
+ my $proto=shift;
+ my $class=ref($proto) || $proto;
+ my ($trid,$otype,$oaction)=@_;
 
  my $self={ version => '2.0.0', lines => {}, trid => $trid, generated_for => $otype.'_'.$oaction };
 
@@ -100,7 +106,7 @@ sub email_body
   push @l,sprintf('%s..: %s',$c,$self->{lines}->{$c});
  }
 
- return Net::DRI::Util::encode('iso-8859-15',join("\n",@l)."\n");
+ return Encode::encode('iso-8859-15',join("\n",@l)."\n",$Encode::FB_CROAK);
 }
 
 sub as_mime
@@ -121,7 +127,7 @@ sub as_mime
 
  ## Subject : ClientID + Name of operation attempted + TRID
  $m->head->replace('Subject',sprintf('%s %s [%s]',$self->client_auth()->{id},$self->{generated_for},$self->trid()));
- $m->head->replace('X-Mailer',sprintf('Net::DRI/%s via %s',$Net::DRI::VERSION,$m->head->get('X-Mailer')));
+ $m->head->replace('X-Mailer',sprintf('Net::DRI %s/%s via %s',$Net::DRI::VERSION,$VERSION,$m->head->get('X-Mailer')));
  return $m;
 }
 
