@@ -1,6 +1,6 @@
 ## Domain Registry Interface, DAS Connection handling
 ##
-## Copyright (c) 2007-2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-####################################################################################################
+#
+# 
+#
+#########################################################################################
 
 package Net::DRI::Protocol::DAS::Connection;
 
 use strict;
-use warnings;
-
-use Net::DRI::Util;
 use Net::DRI::Data::Raw;
 use Net::DRI::Protocol::ResultStatus;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -49,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -63,32 +65,21 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-sub read_data
+sub get_data
 {
- my ($class,$to,$sock)=@_;
+ shift if ($_[0] eq __PACKAGE__);
+ my ($to,$sock)=@_;
 
- my @r;
+ my @a;
  while(my $l=$sock->getline())
  {
-  chomp $l;
-  push @r,Net::DRI::Util::decode_ascii($l);
+  chomp($l);
+  push @a,$l;
   last if $l=~m/^Status: /;
  }
 
- die(Net::DRI::Protocol::ResultStatus->new_error('COMMAND_FAILED_CLOSING','Unable to read answer (connection closed by registry ?)','en')) unless (@r && $r[-1]=~m/^Status: /);
- return Net::DRI::Data::Raw->new_from_array(\@r);
-}
-
-sub write_message
-{
- my ($class,$to,$msg)=@_;
- return Net::DRI::Util::encode_ascii($msg->as_string());
-}
-
-sub transport_default
-{
- my ($self,$tname)=@_;
- return (defer => 1, close_after => 1, socktype => 'tcp', remote_port => 4343);
+ die(Net::DRI::Protocol::ResultStatus->new_error('COMMAND_SYNTAX_ERROR','Unable to read answer (connection closed by registry ?)','en')) unless $a[-1]=~m/^Status: /;
+ return Net::DRI::Data::Raw->new_from_array(\@a);
 }
 
 ####################################################################################################
