@@ -1,6 +1,6 @@
 ## Domain Registry Interface, DAS Domain commands
 ##
-## Copyright (c) 2007,2009,2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,16 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::DAS::Domain;
 
 use strict;
-use warnings;
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -48,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2009,2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -76,13 +80,13 @@ sub check
 {
  my ($po,$domain,$rd)=@_;
  my $mes=$po->message();
- Net::DRI::Exception->die(1,'protocol/DAS',2,'Domain name needed') unless $domain;
- Net::DRI::Exception->die(1,'protocol/DAS',10,'Invalid domain name: '.$domain) unless Net::DRI::Util::is_hostname($domain);
  my $tld=$po->tld();
- $domain=~s/\.${tld}$// if defined $tld;
+ my ($dom)=($domain=~m/^(\S+)\.${tld}$/i);
+ Net::DRI::Exception->die(1,'protocol/DAS',2,'Domain name needed') unless $dom;
+ Net::DRI::Exception->die(1,'protocol/DAS',10,'Invalid domain name: '.$dom) unless Net::DRI::Util::is_hostname($dom);
  $mes->command('get');
- $mes->command_param(lc($domain));
- return;
+ $mes->command_param(lc($dom));
+ $mes->command_tld($tld);
 }
 
 sub check_parse
@@ -92,16 +96,11 @@ sub check_parse
  return unless $mes->is_success();
 
  my $rr=$mes->response();
- my $domain=(defined $po->tld())? lc($rr->{Domain}.'.'.$po->tld()) : lc($rr->{Domain});
+ my $domain=lc($rr->{Domain}.'.'.$po->tld());
  $rinfo->{domain}->{$domain}->{action}='check';
  my $s=uc($rr->{Status});
- $rinfo->{domain}->{$domain}->{exist}=($s eq 'FREE' || $s eq 'AVAILABLE')? 0 : 1;
- $rinfo->{domain}->{$domain}->{exist_reason}=$rr->{Status};
- if (exists $rr->{'IDNA Domain'})
- {
-  $rinfo->{domain}->{$domain}->{ace}=(defined $po->tld())? lc($rr->{'IDNA Domain'}.'.'.$po->tld()) : lc($rr->{'IDNA Domain'});
- }
- return;
+ $rinfo->{domain}->{$domain}->{exist}=($s eq 'FREE')? 0 : 1;
+ $rinfo->{domain}->{$domain}->{exist_reason}=$s;
 }
 
 ####################################################################################################
