@@ -1,6 +1,6 @@
-## Domain Registry Interface, EPP Protocol (RFC 3730,3731,3732,3733,3734,3735)
+## Domain Registry Interface, EPP Protocol (RFC 4930,4931,4932,4933,4934,3735)
 ##
-## Copyright (c) 2005,2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2006,2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -27,13 +27,13 @@ use Net::DRI::Protocol::EPP::Message;
 use Net::DRI::Protocol::EPP::Core::Status;
 use Net::DRI::Data::Contact;
 
-our $VERSION=do { my @r=(q$Revision: 1.7 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.8 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP - EPP Protocol (RFC 3730,3731,3732,3733,3734,3735) for Net::DRI
+Net::DRI::Protocol::EPP - EPP Protocol (RFC 4930,4931,4932,4933,4934 obsoleting RFC 3730,3731,3732,3733,3734 and RFC 3735) for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -57,7 +57,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2006 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2006,2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -113,10 +113,10 @@ sub _load
 
  my @core=('Session','RegistryMessage','Domain','Contact');
  push @core,'Host' unless $self->{hostasattr};
- my @class=map { "Net::DRI::Protocol::EPP::Core::".$_ } @core;
+ my @class=map { 'Net::DRI::Protocol::EPP::Core::'.$_ } @core;
  if (defined($extrah) && $extrah)
  {
-  push @class,map { s!/!::!g; $_; } map { /::/? $_ : 'Net::DRI::Protocol::EPP::Extensions::'.$_ } (ref($extrah)? @$extrah : ($extrah));
+  push @class,map { my $f=$_; $f=~s!/!::!g; $f; } map { /::/? $_ : 'Net::DRI::Protocol::EPP::Extensions::'.$_ } (ref($extrah)? @$extrah : ($extrah));
  }
 
  $self->SUPER::_load(@class);
