@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .CAT EPP extensions
 ##
-## Copyright (c) 2006,2008,2009,2012,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,15 +10,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::CAT;
 
 use strict;
-use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
+use Net::DRI::Data::Contact::CAT;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -47,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2009,2012,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -60,23 +66,33 @@ See the LICENSE file that comes with this distribution for more details.
 =cut
 
 ####################################################################################################
-
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
- $self->ns({ cx     => 'http://xmlns.domini.cat/epp/contact-ext-1.0',
-             dx     => 'http://xmlns.domini.cat/epp/domain-ext-1.0',
-             defreg => 'http://xmlns.domini.cat/epp/defreg-1.0',
-          });
- $self->capabilities('host_update','name',undef);
- $self->capabilities('domain_update','name_variant',['add','del']);
- foreach my $o (qw/lang maintainer intended_use registrant_disclosure/) { $self->capabilities('domain_update',$o,['set']); }
- foreach my $o (qw/status contact/) { $self->capabilities('defreg_update',$o,['add','del']); }
- foreach my $o (qw/registrant auth maintainer trademark/) { $self->capabilities('defreg_update',$o,['set']); }
- return;
-}
+ my $h=shift;
+ my $c=ref($h) || $h;
 
-sub default_extensions { return qw/CAT::Domain CAT::Contact CAT::DefensiveRegistration/; }
+ my ($drd,$version,$extrah)=@_;
+ my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
+
+ $e{'Net::DRI::Protocol::EPP::Extensions::CAT::Domain'}=1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::CAT::Contact'}=1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::CAT::DefensiveRegistration'}=1;
+
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
+
+ $self->{ns}->{puntcat_contact}=['http://xmlns.domini.cat/epp/contact-ext-1.0','puntcat-contact-ext-1.0.xsd'];
+ $self->{ns}->{puntcat_domain} =['http://xmlns.domini.cat/epp/domain-ext-1.0','puntcat-domain-ext-1.0.xsd'];
+ $self->{ns}->{puntcat_defreg} =['http://xmlns.domini.cat/epp/defreg-1.0','puntcat-defreg-1.0.xsd'];
+
+ my $rcapa=$self->capabilities();
+ delete($rcapa->{host_update}->{name});
+
+ my $rfact=$self->factories();
+ $rfact->{contact}=sub { return Net::DRI::Data::Contact::CAT->new(); };
+
+ bless($self,$c); ## rebless
+ return $self;
+}
 
 ####################################################################################################
 1;
