@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .COOP EPP extensions
 ##
-## Copyright (c) 2006,2008,2009,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,16 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::COOP;
 
 use strict;
-use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 use Net::DRI::Data::Contact::COOP;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -48,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2009,2013,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -61,17 +65,27 @@ See the LICENSE file that comes with this distribution for more details.
 =cut
 
 ####################################################################################################
-
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
- $self->ns({ coop => 'http://www.nic.coop/contactCoopExt-1.0' });
- $self->capabilities('contact_update','sponsor',['add','del']);
- $self->factories('contact',sub { return Net::DRI::Data::Contact::COOP->new() });
- return;
-}
+ my $h=shift;
+ my $c=ref($h) || $h;
 
-sub default_extensions { return qw/COOP::Contact/; }
+ my ($drd,$version,$extrah,$defproduct)=@_;
+ my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
+
+ $e{'Net::DRI::Protocol::EPP::Extensions::COOP::Contact'}=1;
+
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
+
+ my $rcapa=$self->capabilities();
+ $rcapa->{contact_update}->{sponsor}=['add','del'];
+
+ my $rfact=$self->factories();
+ $rfact->{contact}=sub { return Net::DRI::Data::Contact::COOP->new() };
+
+ bless($self,$c);
+ return $self;
+}
 
 ####################################################################################################
 1;
