@@ -1,7 +1,7 @@
 ## Domain Registry Interface, .COOP Contact EPP extension commands
 ## (based on document: EPP Extensions for the .coop TLD Registrant Verification version 1.6)
 ##
-## Copyright (c) 2006,2008,2013-2014,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,15 +11,18 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::COOP::Contact;
 
 use strict;
-use warnings;
 
-use Net::DRI::Exception;
-use Net::DRI::Util;
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
+our $NS='http://www.nic.coop/contactCoopExt-1.0';
 
 =pod
 
@@ -49,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2013-2014,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -81,6 +84,12 @@ sub register_commands
 
 ####################################################################################################
 
+sub build_command_extension
+{
+ my ($mes,$epp,$tag)=@_;
+ return $mes->command_extension_register($tag,sprintf('xmlns:coop="%s"',$NS));
+}
+
 sub build_sponsors
 {
  my $s=shift;
@@ -99,6 +108,7 @@ sub build_prefs
 sub create
 {
  my ($epp,$contact)=@_;
+ my $mes=$epp->message();
 
  ## validate() has been called
  my @n;
@@ -107,13 +117,14 @@ sub create
 
  return unless @n;
 
- $epp->message()->command_extension('coop', ['create', @n]);
- return;
+ my $eid=build_command_extension($mes,$epp,'coop:create');
+ $mes->command_extension($eid,\@n);
 }
 
 sub update
 {
  my ($epp,$domain,$todo)=@_;
+ my $mes=$epp->message();
 
  my @n;
  push @n,['coop:add',build_sponsors($todo->add('sponsor'))] if $todo->add('sponsor');
@@ -122,8 +133,8 @@ sub update
  push @n,['coop:chg',\@nn] if @nn;
  return unless @n;
 
- $epp->message()->command_extension('coop', ['update', @n]);
- return;
+ my $eid=build_command_extension($mes,$epp,'coop:update');
+ $mes->command_extension($eid,\@n);
 }
 
 sub info_parse
@@ -132,23 +143,21 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('coop','infData');
+ my $infdata=$mes->get_content('infData',$NS,1);
  return unless $infdata;
 
  my $s=$rinfo->{contact}->{$oname}->{self};
 
- my $ns=$mes->ns('coop');
- my $el=$infdata->getChildrenByTagNameNS($ns,'state');
+ my $el=$infdata->getElementsByTagNameNS($NS,'state');
  $s->state($el->get_node(1)->getAttribute('code')) if defined($el->get_node(1));
 
- my @s=map { $_->getFirstChild()->getData() } $infdata->getChildrenByTagNameNS($ns,'sponsor');
+ my @s=map { $_->getFirstChild()->getData() } $infdata->getElementsByTagNameNS($NS,'sponsor');
  $s->sponsors(\@s) if @s;
 
- $el=$infdata->getChildrenByTagNameNS($ns,'langPref');
+ $el=$infdata->getElementsByTagNameNS($NS,'langPref');
  $s->lang($el->get_node(1)->getFirstChild()->getData()) if defined($el->get_node(1));
- $el=$infdata->getChildrenByTagNameNS($ns,'mailingListPref');
+ $el=$infdata->getElementsByTagNameNS($NS,'mailingListPref');
  $s->mailing_list($el->get_node(1)->getFirstChild()->getData()) if defined($el->get_node(1));
- return;
 }
 
 ####################################################################################################
@@ -157,9 +166,10 @@ sub domain_create
 {
  my ($epp,$domain,$rd)=@_;
 
- Net::DRI::Exception::usererr_insufficient_parameters('registrant is mandatory') unless (Net::DRI::Util::has_contact($rd) && $rd->{contact}->get('registrant'));
+ Net::DRI::Exception::usererr_insufficient_parameters('registrant is mandatory') unless (defined($rd) && (ref($rd) eq 'HASH') && exists($rd->{contact}) 
+                                                                                         && UNIVERSAL::isa($rd->{contact},'Net::DRI::Data::ContactSet')
+                                                                                         && $rd->{contact}->get('registrant'));
  Net::DRI::Exception::usererr_insufficient_parameters('registrant org is mandatory') unless $rd->{contact}->get('registrant')->org();
- return;
 }
 
 sub domain_parse
@@ -168,11 +178,11 @@ sub domain_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $data=$mes->get_extension('coop','stateChange');
+ my $data=$mes->get_content('stateChange',$NS,1);
  return unless $data;
 
- my $id=$data->getChildrenByTagNameNS($mes->ns('coop'),'id')->get_node(1)->getFirstChild()->getData();
- $rinfo->{contact}->{$id}->{state}=$data->getChildrenByTagNameNS($mes->ns('coop'),'state')->get_node(1)->getAttribute('code');
+ my $id=$data->getElementsByTagNameNS($NS,'id')->get_node(1)->getFirstChild()->getData();
+ $rinfo->{contact}->{$id}->{state}=$data->getElementsByTagNameNS($NS,'state')->get_node(1)->getAttribute('code');
  $rinfo->{contact}->{$id}->{action}='verification_review';
 
  if (defined($otype) && ($otype eq 'domain') && defined($oaction) && ($oaction eq 'create' || $oaction eq 'update'))
@@ -180,7 +190,6 @@ sub domain_parse
   $rinfo->{domain}->{$oname}->{registrant_id}=$id;
   $rinfo->{domain}->{$oname}->{registrant_state}=$rinfo->{contact}->{$id}->{state};
  }
- return;
 }
 
 ####################################################################################################
