@@ -1,7 +1,7 @@
 ## Domain Registry Interface, CentralNic DNS TTL EPP extension
 ## (http://labs.centralnic.com/epp/ext/ttl.php)
 ##
-## Copyright (c) 2007,2008,2010,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,16 +11,18 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::CentralNic::TTL;
 
 use strict;
-use warnings;
 
 use DateTime::Duration;
 
-use Net::DRI::Util;
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -50,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2010,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -74,6 +76,13 @@ sub register_commands
  return { 'domain' => \%tmp };
 }
 
+sub capabilities_add
+{
+ return { 'domain_update' => { 'ttl' => ['set'] } };
+}
+
+our @NS=qw/urn:centralnic:params:xml:ns:ttl-1.0 ttl-1.0.xsd/;
+
 ####################################################################################################
 ########### Query commands
 
@@ -83,14 +92,13 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('ttl','infData');
+ my $infdata=$mes->get_content('infData',$NS[0],1);
  return unless $infdata;
 
- my @secs=$infdata->getChildrenByTagNameNS($mes->ns('ttl'),'secs');
+ my @secs=$infdata->getElementsByTagNameNS($NS[0],'secs');
  return unless @secs;
 
- $rinfo->{domain}->{$oname}->{ttl}=DateTime::Duration->new(seconds => $secs[0]->textContent());
- return;
+ $rinfo->{domain}->{$oname}->{ttl}=DateTime::Duration->new(seconds => $secs[0]->getFirstChild()->getData());
 }
 
 ############ Transform commands
@@ -98,22 +106,26 @@ sub info_parse
 sub create
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- return unless (exists($rd->{ttl}) && ((ref($rd->{ttl}) && Net::DRI::Util::is_class($rd->{ttl},'DateTime::Duration')) || $rd->{ttl}=~m/^\d+$/));
+ return unless (exists($rd->{ttl}) && ((ref($rd->{ttl}) && UNIVERSAL::isa($rd->{ttl},'DateTime::Duration')) || $rd->{ttl}=~m/^\d+$/));
 
- $epp->message()->command_extension('ttl', ['create', ['secs', ref $rd->{ttl} ? $rd->{ttl}->in_units('seconds') : $rd->{ttl}]]);
- return;
+ my $eid=$mes->command_extension_register('ttl:create',sprintf('xmlns:ttl="%s" xsi:schemaLocation="%s %s"',$NS[0],@NS));
+ my @n=(['ttl:secs',ref($rd->{ttl})? $rd->{ttl}->in_units('seconds') : $rd->{ttl}]);
+ $mes->command_extension($eid,\@n);
 }
 
 sub update
 {
  my ($epp,$domain,$todo)=@_;
+ my $mes=$epp->message();
 
  my $toset=$todo->set('ttl');
- return unless (defined $toset && ((ref $toset && Net::DRI::Util::is_class($toset,'DateTime::Duration')) || $toset=~m/^\d+$/));
+ return unless (defined($toset) && ((ref($toset) && UNIVERSAL::isa($toset,'DateTime::Duration')) || $toset=~m/^\d+$/));
 
- $epp->message()->command_extension('ttl', ['update', ['secs', ref $toset ? $toset->in_units('seconds') : $toset]]);
- return;
+ my $eid=$mes->command_extension_register('ttl:update',sprintf('xmlns:ttl="%s" xsi:schemaLocation="%s %s"',$NS[0],@NS));
+ my @n=(['ttl:secs',ref($toset)? $toset->in_units('seconds') : $toset]);
+ $mes->command_extension($eid,\@n);
 }
 
 ####################################################################################################
