@@ -1,7 +1,7 @@
 ## Domain Registry Interface, CentralNic Web Forwarding EPP extension
 ## (http://labs.centralnic.com/epp/ext/wf.php)
 ##
-## Copyright (c) 2007,2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,13 +11,16 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::CentralNic::WebForwarding;
 
 use strict;
-use warnings;
-use feature 'state';
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -47,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -64,15 +67,20 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- state $domain = {
-                  create => [ \&create ],
-                  update => [ \&update ],
-                  info   => [ undef, \&info_parse ],
-                 };
- state $commands = { 'domain' => $domain };
- return $commands;
+ my %tmp=( create => [ \&create ],
+            update => [ \&update ],
+            info   => [ undef, \&info_parse ],
+          );
+ return { 'domain' => \%tmp };
 }
 
+sub capabilities_add
+{
+ return { 'domain_update' => { 'web_forwarding' => ['set'] } };
+}
+
+our @NS=qw/urn:centralnic:params:xml:ns:wf-1.0 wf-1.0.xsd/;
+
 ####################################################################################################
 ########### Query commands
 
@@ -82,14 +90,13 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('wf','infData');
+ my $infdata=$mes->get_content('infData',$NS[0],1);
  return unless $infdata;
 
- my @c=$infdata->getChildrenByTagNameNS($mes->ns('wf'),'url');
+ my @c=$infdata->getElementsByTagNameNS($NS[0],'url');
  return unless @c;
 
  $rinfo->{domain}->{$oname}->{web_forwarding}=$c[0]->getFirstChild()->getData();
- return;
 }
 
 ############ Transform commands
@@ -97,22 +104,26 @@ sub info_parse
 sub create
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
  return unless (exists($rd->{web_forwarding}) && defined($rd->{web_forwarding}));
 
- $epp->message()->command_extension('wf', ['create', ['url', $rd->{web_forwarding}]]);
- return;
+ my $eid=$mes->command_extension_register('wf:create',sprintf('xmlns:wf="%s" xsi:schemaLocation="%s %s"',$NS[0],@NS));
+ my @n=(['wf:url',$rd->{web_forwarding}]);
+ $mes->command_extension($eid,\@n);
 }
 
 sub update
 {
  my ($epp,$domain,$todo)=@_;
+ my $mes=$epp->message();
 
  my $toset=$todo->set('web_forwarding');
  return unless defined($toset);
 
- $epp->message()->command_extension('wf', ['update', ['url',$toset]]);
- return;
+ my $eid=$mes->command_extension_register('wf:update',sprintf('xmlns:wf="%s" xsi:schemaLocation="%s %s"',$NS[0],@NS));
+ my @n=(['wf:url',$toset]);
+ $mes->command_extension($eid,\@n);
 }
 
 ####################################################################################################
