@@ -1,7 +1,7 @@
 ## Domain Registry Interface, DNSBE Contact EPP extension commands
 ## (based on Registration_guidelines_v4_7_2-Part_4-epp.pdf)
 ##
-## Copyright (c) 2006,2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,12 +11,16 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-####################################################################################################
+#
+# 
+#
+#########################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::DNSBE::Contact;
 
 use strict;
-use warnings;
+
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -46,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -63,7 +67,7 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- my %tmp=(
+ my %tmp=( 
           create            => [ \&create, undef ],
           update            => [ \&update, undef ],
           info              => [ undef, \&info_parse ],
@@ -74,9 +78,18 @@ sub register_commands
 
 ####################################################################################################
 
+sub build_command_extension
+{
+ my ($mes,$epp,$tag)=@_;
+
+ my @ns=@{$mes->ns->{dnsbe}};
+ return $mes->command_extension_register($tag,sprintf('xmlns:dnsbe="%s" xsi:schemaLocation="%s %s"',$ns[0],$ns[0],$ns[1]));
+}
+
 sub create
 {
  my ($epp,$contact)=@_;
+ my $mes=$epp->message();
 
  ## validate() has been called, we are sure that type & lang exists
  my @n;
@@ -84,13 +97,14 @@ sub create
  push @n,['dnsbe:vat',$contact->vat()] if $contact->vat();
  push @n,['dnsbe:lang',$contact->lang()];
 
- $epp->message()->command_extension('dnsbe', ['ext', ['create', ['contact', @n]]]);
- return;
+ my $eid=build_command_extension($mes,$epp,'dnsbe:ext');
+ $mes->command_extension($eid,['dnsbe:create',['dnsbe:contact',@n]]);
 }
 
 sub update
 {
  my ($epp,$domain,$todo)=@_;
+ my $mes=$epp->message();
 
  my $newc=$todo->set('info');
  return unless ($newc && (defined($newc->vat()) || defined($newc->lang())));
@@ -99,8 +113,8 @@ sub update
  push @n,['dnsbe:vat',$newc->vat()]   if defined($newc->vat());
  push @n,['dnsbe:lang',$newc->lang()] if defined($newc->lang());
 
- $epp->message()->command_extension('dnsbe', ['ext', ['update', ['contact', ['chg', @n]]]]);
- return;
+ my $eid=build_command_extension($mes,$epp,'dnsbe:ext');
+ $mes->command_extension($eid,['dnsbe:update',['dnsbe:contact',['dnsbe:chg',@n]]]);
 }
 
 sub info_parse
@@ -109,18 +123,17 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('dnsbe','infData');
+ my $infdata=$mes->get_content('infData',$mes->ns('dnsbe'),1);
  return unless $infdata;
 
  my $s=$rinfo->{contact}->{$oname}->{self};
 
- my $el=$infdata->getChildrenByTagNameNS($mes->ns('dnsbe'),'type');
+ my $el=$infdata->getElementsByTagNameNS($mes->ns('dnsbe'),'type');
  $s->type($el->get_node(1)->getFirstChild()->getData());
- $el=$infdata->getChildrenByTagNameNS($mes->ns('dnsbe'),'vat');
+ $el=$infdata->getElementsByTagNameNS($mes->ns('dnsbe'),'vat');
  $s->vat($el->get_node(1)->getFirstChild()->getData()) if defined($el->get_node(1));
- $el=$infdata->getChildrenByTagNameNS($mes->ns('dnsbe'),'lang');
+ $el=$infdata->getElementsByTagNameNS($mes->ns('dnsbe'),'lang');
  $s->lang($el->get_node(1)->getFirstChild()->getData());
- return;
 }
 
 ####################################################################################################
