@@ -1,6 +1,6 @@
-## Domain Registry Interface, EPP .US Contact NEXUS Extensions
+## Domain Registry Interface, EPP .US Contact NEXUS Extensions (draft-liu-epp-usTLD-00)
 ##
-## Copyright (c) 2005,2006,2008,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,21 +10,25 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::US::Contact;
 
 use strict;
-use warnings;
-use feature 'state';
 
 use Net::DRI::Util;
+use Net::DRI::Exception;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP::Extensions::US::Contact - .US EPP Contact NEXUS Extensions for Net::DRI
+Net::DRI::Protocol::EPP::Extensions::US::Contact - EPP .US Contact NEXUS Extensions (draft-liu-epp-usTLD-00) for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -48,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2006,2008,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -65,22 +69,13 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- state $cmds = { 'contact' => {
-                               info   => [ undef, \&info_parse ],
-                               create => [ \&create, undef ],
-                               update => [ \&update, undef ],
-                              }
-               };
+ my %tmp=(
+           info   => [ undef, \&info_parse ],
+           create => [ \&create, undef ],
+           update => [ \&update, undef ],
+         );
 
- return $cmds;
-}
-
-sub setup
-{
- my ($class,$po,$version)=@_;
- state $rns = { 'neulevel' => 'urn:ietf:params:xml:ns:neulevel-1.0' };
- $po->ns($rns);
- return;
+ return { 'contact' => \%tmp };
 }
 
 ####################################################################################################
@@ -101,7 +96,6 @@ sub info_parse
 
  $contact->application_purpose($tmp{AppPurpose}) if exists($tmp{AppPurpose});
  $contact->nexus_category($tmp{NexusCategory})   if exists($tmp{NexusCategory});
- return;
 }
 
 ############ Transform commands
@@ -109,29 +103,31 @@ sub info_parse
 sub create
 {
  my ($epp,$contact)=@_;
+ my $mes=$epp->message();
 
- return unless Net::DRI::Util::isa_contact($contact,'Net::DRI::Data::Contact::US');
+ return unless (UNIVERSAL::isa($contact,'Net::DRI::Data::Contact::US'));
 
  my $str=sprintf('AppPurpose=%s NexusCategory=%s',$contact->application_purpose(),$contact->nexus_category());
- $epp->message()->command_extension('neulevel', ['extension', ['neulevel:unspec',$str]]);
- return;
+ my $eid=$mes->command_extension_register('','');
+ $mes->command_extension($eid,[$str]);
 }
 
 sub update
 {
  my ($epp,$contact,$todo)=@_;
+ my $mes=$epp->message();
 
  my $newc=$todo->set('info');
- return unless Net::DRI::Util::isa_contact($newc,'Net::DRI::Data::Contact::US');
+ return unless $newc && UNIVERSAL::isa($newc,'Net::DRI::Data::Contact::US');
 
  my @tmp;
  push @tmp,'AppPurpose='.$newc->application_purpose() if (defined($newc->application_purpose()));
  push @tmp,'NexusCategory='.$newc->nexus_category()   if (defined($newc->nexus_category()));
 
  return unless @tmp;
-
- $epp->message()->command_extension('neulevel', ['extension', ['neulevel:unspec',join(' ',@tmp)]]);
- return;
+ 
+ my $eid=$mes->command_extension_register('','');
+ $mes->command_extension($eid,[join(' ',@tmp)]);
 }
 
 ####################################################################################################
