@@ -21,7 +21,7 @@ use strict;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
-our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -74,6 +74,8 @@ sub new
 
  $e{'Net::DRI::Protocol::EPP::Extensions::VeriSign::NameStore'}=1;
  $e{'Net::DRI::Protocol::EPP::Extensions::VeriSign::Sync'}=1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::VeriSign::PollLowBalance'}=1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::VeriSign::PollRGP'}=1;
  ## We do no load automatically IDNLanguage & WhoisInfo as we do not know if they are mandatory
  ## NameStore seems mandatory, and Sync is just another operation, hence optional in all cases
  if (exists($e{':full'})) ## useful shortcut, modeled after Perl itself
@@ -81,10 +83,13 @@ sub new
   delete($e{':full'});
   $e{'Net::DRI::Protocol::EPP::Extensions::VeriSign::IDNLanguage'}=1;
   $e{'Net::DRI::Protocol::EPP::Extensions::VeriSign::WhoisInfo'}=1;
+  $e{'Net::DRI::Protocol::EPP::Extensions::GracePeriod'}=1;
  }
 
  my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
  $self->default_parameters()->{subproductid}=$defproduct || '_auto_';
+ $self->default_parameters()->{whois_info}=0;
+ $self->default_parameters()->{breaks_rfc3915}=1;
 
  bless($self,$c); ## rebless
  return $self;
