@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Whois Message
 ##
-## Copyright (c) 2007-2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,12 +10,16 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::Whois::Message;
 
 use strict;
-use warnings;
+
+use Encode ();
 
 use Net::DRI::Protocol::ResultStatus;
 use Net::DRI::Exception;
@@ -24,6 +28,8 @@ use Net::DRI::Util;
 use base qw(Class::Accessor::Chained::Fast Net::DRI::Protocol::Message);
 __PACKAGE__->mk_accessors(qw(version errcode errmsg errlang command cltrid response response_raw));
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -52,7 +58,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -68,7 +74,10 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my ($class,$trid)=@_;
+ my $proto=shift;
+ my $class=ref($proto) || $proto;
+ my $trid=shift;
+
  my $self={
            errcode => -1000,
 	   response => {},
@@ -87,22 +96,23 @@ sub result_status
  my %C=( 0 => 1500, ## Command successful + connection closed
        );
  my $c=$self->errcode();
- my $rs=Net::DRI::Protocol::ResultStatus->new('whois',$c,exists($C{$c})? $C{$c} : 'COMMAND_FAILED',$self->is_success(),$self->errmsg(),$self->errlang(),undef);
+ my $rs=Net::DRI::Protocol::ResultStatus->new('whois',$c,exists($C{$c})? $C{$c} : $Net::DRI::Protocol::ResultStatus::EPP_CODES{GENERIC_ERROR},$self->is_success(),$self->errmsg(),$self->errlang(),undef);
  $rs->_set_trid([ $self->cltrid(),undef ]);
  return $rs;
 }
 
 sub as_string
 {
- my ($self)=@_;
+ my ($self,$to)=@_;
  my $s=sprintf("%s\x0d\x0a",$self->command());
- return $s;
+ return Encode::encode('ascii',$s);
 }
 
 sub parse
 {
  my ($self,$dc,$rinfo)=@_;
- my @d=$dc->as_array();
+ my @d=map { Encode::decode('ascii',$_) } $dc->as_array();
+
  my %info;
  foreach my $l (grep { /:/ } @d)
  {
@@ -120,8 +130,15 @@ sub parse
  $self->errcode(0);
  $self->response(\%info);
  $self->response_raw(\@d);
- return;
 }
 
-####################################################################################################
+sub get_name_from_message
+{
+ my ($self)=@_;
+ my $d=$self->command();
+ $d=$1 if ($d=~m/^domain (\S+)/);
+ return lc($d);
+}
+
+########################################################################
 1;
